@@ -308,22 +308,36 @@ def _generate_repository(
         click.echo(click.style(f"ERROR: Error: {file_path} already exists", fg='red'))
         return
 
-    # Check if entity exists
+    # Check if entity or aggregate exists
     entity_path = base_path / "domain" / "entities" / f"{entity_file}.py"
-    if not entity_path.exists():
+    aggregate_path = base_path / "domain" / "aggregates" / f"{entity_file}.py"
+    aggregate_exists = aggregate_path.exists()
+    entity_exists = entity_path.exists()
+
+    if not entity_exists and not aggregate_exists:
         click.echo(
             click.style(
-                f"⚠️  Warning: Entity {entity_name} does not exist at {entity_path.relative_to(project_root)}",
+                f"⚠️  Warning: neither Entity nor Aggregate named {entity_name} exists "
+                f"(checked {entity_path.relative_to(project_root)} and {aggregate_path.relative_to(project_root)})",
                 fg='yellow',
             )
         )
-
-        if click.confirm(f"Do you want to create the entity {entity_name}?", default=True):
+        choice = click.prompt(
+            "Create missing type",
+            type=click.Choice(['entity', 'aggregate'], case_sensitive=False),
+            default='entity'
+        )
+        if choice == 'entity':
             _generate_entity(project_root, project_name, entity_name, entity_file)
-            click.echo()  # Empty line for readability
         else:
-            click.echo(click.style(f"ERROR: Cannot create repository without entity {entity_name}", fg='red'))
-            return
+            _generate_aggregate(project_root, project_name, entity_name, entity_file)
+        click.echo()  # spacing
+    else:
+        # Show what we found
+        if entity_exists:
+            click.echo(click.style(f"✔ Found entity at {entity_path.relative_to(project_root)}", fg='green'))
+        if aggregate_exists:
+            click.echo(click.style(f"✔ Found aggregate at {aggregate_path.relative_to(project_root)}", fg='green'))
 
     file_path.parent.mkdir(parents=True, exist_ok=True)
     content = render_repository_interface(class_name, entity_name, entity_file)
@@ -430,10 +444,7 @@ def _generate_interactor(project_root: Path, project_name: str, class_name: str,
 
     # Prepare file names and class names
     input_file = f"{file_name}_{cqrs_type}"  # e.g., create_user_command.py
-    if cqrs_type == 'query':
-        input_class = f"{class_name}{cqrs_type}"  # lower suffix for queries
-    else:
-        input_class = f"{class_name}{cqrs_type.capitalize()}"  # CreateUserCommand
+    input_class = f"{class_name}{cqrs_type.capitalize()}"  # CreateUserCommand or GetUserQuery
     input_var = cqrs_type  # command or query
     response_file = f"{file_name}_response"
     response_class = f"{class_name}Result"
@@ -441,12 +452,19 @@ def _generate_interactor(project_root: Path, project_name: str, class_name: str,
     # Ask for description
     description = click.prompt("Description", default=f"{class_name} {cqrs_type}")
 
+    # Build import base module (handles bounded context)
+    if base_path == project_root:
+        app_module = "application"
+    else:
+        app_module = f"{base_path.relative_to(project_root).as_posix().replace('/', '.')}.application"
+
     # Generate handler.py
     handler_content = render_cqrs_handler(
         class_name=class_name,
         handler_type=handler_type,
         layer_folder=layer_folder,
         folder_name=folder_name,
+        app_module=app_module,
         input_file=input_file,
         input_class=input_class,
         input_var=input_var,
@@ -491,11 +509,6 @@ __all__ = [
     click.echo(f"+ Created {click.style(str(init_file.relative_to(project_root)), fg='green')}")
 
     # Usage instructions
-    # Build import path reflecting bounded context (if any)
-    if base_path == project_root:
-        app_module = "application"
-    else:
-        app_module = f"{base_path.relative_to(project_root).as_posix().replace('/', '.')}.application"
     click.echo(f"\nUsage:")
     click.echo(f"   from {app_module}.{layer_folder}.{folder_name} import {class_name}Handler, {input_class}")
     click.echo(f"   {input_var} = {input_class}(...)  # Add your parameters")
