@@ -1,6 +1,6 @@
 """Scaffolding helpers for Vega CLI."""
 
-from .vega_web import create_vega_web_scaffold
+from .vega_web import create_vega_web_scaffold, create_vega_web_scaffold_in_context
 from .sqlalchemy import create_sqlalchemy_scaffold
 
 # Backward compatibility alias
@@ -8,6 +8,7 @@ create_fastapi_scaffold = create_vega_web_scaffold
 
 __all__ = [
     "create_vega_web_scaffold",
+    "create_vega_web_scaffold_in_context",
     "create_fastapi_scaffold",  # Deprecated: use create_vega_web_scaffold
     "create_sqlalchemy_scaffold",
 ]
