@@ -1,11 +1,15 @@
 """Utility modules for Vega CLI"""
-from .naming import NamingConverter
+from .naming import NamingConverter, to_snake_case, to_pascal_case, to_camel_case, to_kebab_case
 from .messages import CLIMessages
 from .validators import validate_project_name, validate_path_exists
 from .async_support import async_command, coro
 
 __all__ = [
     "NamingConverter",
+    "to_snake_case",
+    "to_pascal_case",
+    "to_camel_case",
+    "to_kebab_case",
     "CLIMessages",
     "validate_project_name",
     "validate_path_exists",
