@@ -1,6 +1,6 @@
 """IOC Container for dependency resolution"""
 import inspect
-from typing import Type, TypeVar, get_type_hints, Dict, Any
+from typing import Type, TypeVar, get_type_hints, Dict, Any, Callable, Tuple, Iterable
 
 from vega.di.scope import _scope_manager, Scope
 
@@ -33,8 +33,10 @@ class Container:
         Args:
             services: Dictionary mapping abstract types to concrete implementations
         """
-        self._services = services or {}
+        self._services: Dict[Type, Type] = services or {}
         self._concrete_services = list(self._services.values())
+        # Factories are stored separately to avoid changing existing semantics.
+        self._factories: Dict[Type, Tuple[Callable[[], Any], Scope]] = {}
 
     def register(self, abstract: Type, concrete: Type):
         """
@@ -48,6 +50,34 @@ class Container:
         if concrete not in self._concrete_services:
             self._concrete_services.append(concrete)
 
+    def register_factory(self, abstract: Type, factory: Callable[[], Any], *, scope: Scope = Scope.TRANSIENT):
+        """
+        Register a factory for an abstract type.
+
+        This keeps backward compatibility by living alongside `register`.
+        """
+        self._factories[abstract] = (factory, scope)
+
+    # --- Public inspection helpers (to reduce direct access to privates) ---
+    def is_registered(self, abstract: Type) -> bool:
+        """Check if an abstract type is registered (class or factory)."""
+        return abstract in self._services or abstract in self._factories
+
+    def has_concrete(self, cls: Type) -> bool:
+        """Check if a concrete implementation is known to the container."""
+        return cls in self._concrete_services
+
+    def get_bindings(self) -> Dict[Type, Any]:
+        """Return a copy of bindings (abstract -> concrete/factory)."""
+        # Factories shadow class bindings when present.
+        merged: Dict[Type, Any] = {**self._services}
+        merged.update({k: v[0] for k, v in self._factories.items()})
+        return dict(merged)
+
+    def iter_concretes(self) -> Iterable[Type]:
+        """Iterate over known concrete classes."""
+        return tuple(self._concrete_services)
+
     def _resolve_constructor_kwargs(self, cls: Type[T]) -> Dict[str, Any]:
         """
         Resolve constructor dependencies for a class.
@@ -82,7 +112,7 @@ class Container:
                 continue
 
             # Resolve dependency recursively
-            if param_type in self._services or param_type in self._concrete_services:
+            if self.is_registered(param_type) or self.has_concrete(param_type):
                 kwargs[param_name] = self.resolve(param_type)
 
         return kwargs
@@ -126,6 +156,32 @@ class Container:
         kwargs = self._resolve_constructor_kwargs(cls)
         return cls(**kwargs)
 
+    def _resolve_factory(self, abstract: Type[T]) -> T:
+        factory, scope = self._factories[abstract]
+        cache_key = f"factory:{abstract.__module__}.{abstract.__name__}"
+
+        def run_factory():
+            return factory()
+
+        if scope == Scope.TRANSIENT:
+            return run_factory()
+
+        return _scope_manager.get_or_create(
+            cache_key=cache_key,
+            scope=scope,
+            factory=run_factory,
+            context_name=f"factory '{abstract.__name__}'"
+        )
+
+    def build(self, cls: Type[T], **provided_kwargs: Any) -> T:
+        """
+        Public helper to instantiate a class with DI plus provided kwargs.
+        Provided kwargs override auto-resolved ones.
+        """
+        kwargs = self._resolve_constructor_kwargs(cls)
+        kwargs.update(provided_kwargs)
+        return cls(**kwargs)
+
     def resolve(self, service: Type[T]) -> T:
         """
         Resolve a service from the registry.
@@ -152,6 +208,10 @@ class Container:
         if not isinstance(service, type):
             raise ValueError(f"Invalid service type: {type(service)}. Expected a class type.")
 
+        # Check if there's a factory registered
+        if service in self._factories:
+            return self._resolve_factory(service)
+
         # Check if it's an abstract interface that needs mapping
         if service in self._services:
             concrete_class = self._services[service]
@@ -163,7 +223,7 @@ class Container:
 
         raise ValueError(
             f"Service {service.__name__} not registered. "
-            f"Available abstracts: {list(self._services.keys())}"
+            f"Available abstracts: {list(self.get_bindings().keys())}"
         )
 
 
